binny

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildFromGoSource

func BuildFromGoSource(file string, module, entrypoint, version string, opts ...run.Option)

func Install

func Install(cmd string) string

Install installs the named executable and returns an absolute path to it

func InstallAll

func InstallAll()

func IsManagedTool

func IsManagedTool(cmd string) bool

func LDFlags

func LDFlags(flags ...string) run.Option

func ManagedToolPath

func ManagedToolPath(cmd string) string

ManagedToolPath returns the full path to a binny managed tool, installing or updating it before returning or returning empty string "" for non-managed tools

func ToolPath

func ToolPath(toolName string) string

Types

This section is empty.

Jump to